==> apache-druid-0.20.2-src.tar.gz: apache-druid-0.20.2-src/web-console/src/components/plural-pair-if-needed/plural-pair-if-needed.spec.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { render } from '@testing-library/react';
import React from 'react';

import { PluralPairIfNeeded } from './plural-pair-if-needed';

describe('plural pair if needed', () => {
  it('works when both counts exist', () => {
    const pluralPairIfNeeded = (
      <PluralPairIfNeeded
        firstCount={2}
        firstSingular="running task"
        secondCount={1}
        secondSingular="pending task"
      />
    );

    const { container } = render(pluralPairIfNeeded);
    expect(container.firstChild).toMatchSnapshot();
  });

  it('works when only first count exists', () => {
    const pluralPairIfNeeded = (
      <PluralPairIfNeeded
        firstCount={2}
        firstSingular="running task"
        secondCount={0}
        secondSingular="pending task"
      />
    );

    const { container } = render(pluralPairIfNeeded);
    expect(container.firstChild).toMatchSnapshot();
  });

  it('works when only second count exists', () => {
    const pluralPairIfNeeded = (
      <PluralPairIfNeeded
        firstCount={0}
        firstSingular="running task"
        secondCount={1}
        secondSingular="pending task"
      />
    );

    const { container } = render(pluralPairIfNeeded);
    expect(container.firstChild).toMatchSnapshot();
  });

  it('works when no counts exist', () => {
    const pluralPairIfNeeded = (
      <PluralPairIfNeeded
        firstCount={0}
        firstSingular="running task"
        secondCount={0}
        secondSingular="pending task"
      />
    );

    const { container } = render(pluralPairIfNeeded);
    expect(container.firstChild).toMatchSnapshot();
  });
});

==> apache-druid-31.0.2-src.tar.gz: apache-druid-31.0.2-src/web-console/src/components/plural-pair-if-needed/plural-pair-if-needed.spec.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { render } from '@testing-library/react';
import React from 'react';

import { PluralPairIfNeeded } from './plural-pair-if-needed';

describe('PluralPairIfNeeded', () => {
  it('works when both counts exist', () => {
    const pluralPairIfNeeded = (
      <PluralPairIfNeeded
        firstCount={2}
        firstSingular="running task"
        secondCount={1}
        secondSingular="pending task"
      />
    );

    const { container } = render(pluralPairIfNeeded);
    expect(container.firstChild).toMatchSnapshot();
  });

  it('works when only first count exists', () => {
    const pluralPairIfNeeded = (
      <PluralPairIfNeeded
        firstCount={2}
        firstSingular="running task"
        secondCount={0}
        secondSingular="pending task"
      />
    );

    const { container } = render(pluralPairIfNeeded);
    expect(container.firstChild).toMatchSnapshot();
  });

  it('works when only second count exists', () => {
    const pluralPairIfNeeded = (
      <PluralPairIfNeeded
        firstCount={0}
        firstSingular="running task"
        secondCount={1}
        secondSingular="pending task"
      />
    );

    const { container } = render(pluralPairIfNeeded);
    expect(container.firstChild).toMatchSnapshot();
  });

  it('works when no counts exist', () => {
    const pluralPairIfNeeded = (
      <PluralPairIfNeeded
        firstCount={0}
        firstSingular="running task"
        secondCount={0}
        secondSingular="pending task"
      />
    );

    const { container } = render(pluralPairIfNeeded);
    expect(container.firstChild).toMatchSnapshot();
  });
});
